import type { DateRange } from '../dateRange'
import type { EntryTagCollection } from '../entryTag'
import type { EntryWithConfig, EntryWithContent } from './shared'

/**
 * This describes aditional information about a blog entry
 * to display when listing the entry on the blog-list page.
 * At minimum, the title should be specified.
 */
export type BlogEntry = {
  date?: DateRange | string | number
  /**[Supports Markdown]
   * Information to summarize an entry
   */
  description?: string
  /**
   * Tags that correspond to filters on the blog-list page if defined
   */
  tags?: string[]
  /**[Supports Markdown]
   * The title of the blog entry
   */
  title: string
  thumbnail?: {
    style: CSSStyleDeclaration
  }
}

export type BlogEntries = { [key: string]:
  & EntryWithContent
  & EntryWithConfig<BlogEntry>
}

export type BlogList = {
  entries: BlogEntries
  tags?: EntryTagCollection
  removeFromView?: boolean
}
